package com.ruoyi.interfaces.mapper;

import java.util.List;

import com.ruoyi.common.annotation.DataSource;
import com.ruoyi.common.enums.DataSourceType;
import com.ruoyi.interfaces.domain.SysMetaField;

/**
 * 元数据字段Mapper接口
 * 
 * @author 朱得糠
 * @date 2025-08-02
 */
@DataSource(DataSourceType.SLAVE)
public interface SysMetaFieldMapper 
{
    /**
     * 查询元数据字段
     * 
     * @param dsCode 元数据字段主键
     * @return 元数据字段
     */
    public SysMetaField selectSysMetaFieldByDsCode(String dsCode);

    /**
     * 查询元数据字段列表
     * 
     * @param sysMetaField 元数据字段
     * @return 元数据字段集合
     */
    public List<SysMetaField> selectSysMetaFieldList(SysMetaField sysMetaField);

    /**
     * 新增元数据字段
     * 
     * @param sysMetaField 元数据字段
     * @return 结果
     */
    public int insertSysMetaField(SysMetaField sysMetaField);

    /**
     * 修改元数据字段
     * 
     * @param sysMetaField 元数据字段
     * @return 结果
     */
    public int updateSysMetaField(SysMetaField sysMetaField);

    /**
     * 删除元数据字段
     * 
     * @param dsCode 元数据字段主键
     * @return 结果
     */
    public int deleteSysMetaField(SysMetaField sysMetaField);

    int deleteSysMetaFieldAll(SysMetaField sysMetaField);
}
